@@ -23,7 +23,6 @@ use strict;
 use Carp;
 use Getopt::Long;
 use Pod::Usage qw(pod2usage);
-use File::Slurp qw(read_file write_file);
 use Geo::BUFR;
 
 # Will be used if neither --tablepath nor $ENV{BUFR_TABLES} is set
@@ -71,14 +70,24 @@ if ($option{tablepath}) {
     Geo::BUFR->set_tablepath(DEFAULT_TABLE_PATH);
 }
 
-my $dumped_message = read_file($infile);
+my $dumped_message = do {
+    local $/; # Enable slurp mode
+    open my $fh, '<', $infile or die "Can't open $infile: $!";
+    <$fh>;
+};
+
 my $bufr = Geo::BUFR->new();
 
+my $buffer = $bufr->reencode_message($dumped_message, $width);
+
 if ($option{outfile}) {
-    my $buffer = $bufr->reencode_message($dumped_message, $width);
-    write_file($option{outfile}, {binmode => ':raw'}, $buffer);
+    my $outfile = $option{outfile};
+    open my $fh, '>', $outfile or die "Can't open $outfile: $!";
+    binmode($fh);
+    print $fh $buffer;
 } else {
-    print $bufr->reencode_message($dumped_message, $width);
+    binmode(STDOUT);
+    print $buffer;
 }
 
 =pod
